from django.contrib import admin
from imagekit.admin import AdminThumbnail

from gallery.models import Album, City, Location, Photo


class CityAdmin(admin.ModelAdmin):
    list_display = ('name',)
    search_fields = ('name',)
    ordering = ('name',)
    list_per_page = 30


class LocationAdmin(admin.ModelAdmin):
    list_display = ('city', 'place')
    list_filter = ('city',)
    ordering = ('city__name',)
    search_fields = ('place', 'city__name',)
    list_per_page = 30


class AlbumAdmin(admin.ModelAdmin):
    prepopulated_fields = {'slug': ('name',)}
    list_display = ('__str__',)
    search_fields = ('name',)
    ordering = ('name',)
    list_per_page = 30


class PhotoAdmin(admin.ModelAdmin):
    list_display = ('__str__', 'album', 'admin_thumbnail',)
    list_display_links = ('__str__',)
    list_editable = ('album',)
    readonly_fields = ['slug', 'taken_at', 'height', 'width', 'exif', ]
    admin_thumbnail = AdminThumbnail(image_field='photo_thumbnail',)


admin.site.register(City, CityAdmin)
admin.site.register(Location, LocationAdmin)
admin.site.register(Album, AlbumAdmin)
admin.site.register(Photo, PhotoAdmin)
